Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PaymentResponse ¶
type VerificationRequest ¶
type VerificationResponse ¶
type VerificationResponse struct {
PaidAt string `json:"paidAt"`
Amount int `json:"amount"`
Result int `json:"result"`
Status int `json:"status"`
RefNumber int `json:"refNumber"`
Description string `json:"description"`
CardNumber string `json:"cardNumber"`
OrderID string `json:"orderId"`
Message string `json:"message"`
}
type Zibal ¶
type Zibal struct {
// contains filtered or unexported fields
}
func New ¶
func New(client client.Transporter, merchant string) (*Zibal, error)
New creates a zibal provider object for user factory request methods
func (*Zibal) RequestPayment ¶
func (z *Zibal) RequestPayment(ctx context.Context, amount uint, callBackUrl, description string) (*PaymentResponse, error)
RequestPayment creates a payment request and returns a status code and authority.
func (*Zibal) VerifyPayment ¶
VerifyPayment verifies a payment and returns the payment details.
Click to show internal directories.
Click to hide internal directories.